# q2-clawback

![](https://github.com/BenKaehler/q2-clawback/workflows/ci/badge.svg)

This is a QIIME 2 plugin. For details on QIIME 2, see https://qiime2.org.

For details on this plugin, please see the [tutorial](https://forum.qiime2.org/t/using-q2-clawback-to-assemble-taxonomic-weights/5859) or the [article](https://doi.org/10.1038/s41467-019-12669-6).

## Ready-made weights now available for common primer, database, and sample habitat combinations

If you like the idea of using taxonomic weights to improve your taxonomic classification accuracy, but don't want to run clawback, please check out our ready-made weights at [readytowear](https://github.com/BenKaehler/readytowear).
